/// <reference types="node" />
/// <reference types="node" />
import { Writable } from "stream";
import { AudioMixerArgs } from "../AudioMixer/AudioMixer";
import { AudioSampleRate, AudioBitDepth, AudioEndianness } from "../Types/AudioTypes";
type preProcessDataType = (data: Buffer) => Buffer;
type SelfRemoveFunction = (audioInput: AudioInput) => void;
interface AudioInputArgs {
    sampleRate?: AudioSampleRate;
    channels?: number;
    bitDepth?: AudioBitDepth;
    endianness?: AudioEndianness;
    volume?: number;
    fillChunk?: boolean;
    preProcessData?: preProcessDataType;
    forceClose?: boolean;
}
declare class AudioInput extends Writable {
    private inputOptions;
    private mixerOptions;
    private audioBuffer;
    private inputClosed;
    private removeInterval;
    private removeSelf;
    constructor(inputArgs: AudioInputArgs, mixerArgs: AudioMixerArgs, removeFunction?: SelfRemoveFunction);
    _write(chunk: Buffer, _: BufferEncoding, callback: (error?: Error) => void): void;
    get getOptions(): AudioInputArgs;
    setVolume(volume: number): this;
    setPreProcessData(preProcessData: preProcessDataType): this;
    setForceClose(forceClose: boolean): this;
    close(): void;
    readAudioChunk(highWaterMark: number | null): Buffer;
    private autoRemoveFunc;
}
export { AudioInput, AudioInputArgs };
